@@ -170,7 +170,7 @@ def run_asc_desc2horz_vert(inps):
     lon_step = float(atr_list[0]['X_STEP'])
     length = int(round((S - N) / lat_step))
     width  = int(round((E - W) / lon_step))
-    print(f'overlaping area in SNWE: {(S, N, W, E)}')
+    print(f'overlapping area in SNWE: {(S, N, W, E)}')
 
 
     ## 2. read LOS data and geometry
@@ -201,10 +201,10 @@ def run_asc_desc2horz_vert(inps):
             print(f'read 2D LOS incidence / azimuth angles from file: {inps.geom_file[i]}')
         else:
             los_inc_angle[i] = ut.incidence_angle(atr, dimension=0, print_msg=False)
-            los_az_angle[i] = ut.heading2azimuth_angle(float(atr['HEADING']))
+            los_az_angle[i] = ut.heading2azimuth_angle(float(atr['HEADING']), look_direction='right')
             print('calculate the constant LOS incidence / azimuth angles from metadata as:')
             print(f'LOS incidence angle: {los_inc_angle[i]:.1f} deg')
-            print(f'LOS azimuth   angle: {los_az_angle[i]:.1f} deg')
+            print(f'LOS azimuth   angle: {los_az_angle[i]:.1f} deg, assuming right-looking radar.')
 
 
     ## 3. decompose LOS displacements into horizontal / Vertical displacements
