@@ -64,7 +64,7 @@ def cmd_line_parse(iargs=None):
     # save argv (to check the manually specified arguments)
     # use iargs        for python call
     # use sys.argv[1:] for command line call
-    inps.argv = iargs if iargs else sys.argv[1:]
+    inps.argv = iargs or sys.argv[1:]
 
     return inps
 
