@@ -24,6 +24,7 @@ SENSOR_NAME_VARIATION = {
     'ksat5' : ['ksat5', 'kompsat5', 'kompsat', 'kmps5'],
     'lt1'   : ['lt1', 'lt', 'lutan', 'lutan1'],
     'ni'    : ['ni', 'nisar'],
+    'saocom': ['saocom', 'sao', 'saocom1a', 'saocom1b'],
     'rs1'   : ['rs1', 'rsat', 'rsat1', 'radarsat', 'radarsat1'],
     'rs2'   : ['rs2', 'rsat2', 'radarsat2'],
     'rcm'   : ['rcm', 'rsatc', 'radarsat-constellation', 'radarsat-constellation-mission'],
@@ -129,7 +130,7 @@ def get_unavco_mission_name(meta_dict):
         return mission_name
 
     # Convert to UNAVCO Mission name
-    ## ERS, ENV, S1, RS1, RS2, CSK, TSX, JERS, ALOS, ALOS2
+    ## ERS, ENV, S1, RS1, RS2, CSK, TSX, JERS, ALOS, ALOS2, SAOCOM
     if value.startswith(('alos', 'palsar')):
         if value.endswith('2'):
             mission_name = 'ALOS2'
@@ -161,6 +162,9 @@ def get_unavco_mission_name(meta_dict):
     elif value.startswith(('tsx', 'tdx', 'terra', 'tandem')):
         mission_name = 'TSX'
 
+    elif value.startswith(('saocom', 'sao')):
+        mission_name = 'SAOCOM'
+
     elif value.startswith('uav'):
         mission_name = 'UAV'
 
@@ -221,6 +225,7 @@ SWOT = {
 # end    date: operational
 # from Table 1 in Jung et al. (2014)
 # https://www.eoportal.org/satellite-missions/terrasar-x
+# Bachmann et al. (2010, IEEE-TGRS), https://doi.org/10.1109/TGRS.2009.2033934
 TSX = {
     # orbit
     'altitude'                   : 514.8e3,   # m, mean value, 505-533 km
@@ -228,8 +233,8 @@ TSX = {
     'repeat_cycle'               : 11,        # day
     # sar / antenna
     'carrier_frequency'          : 9.65e9,    # Hz
-    'antenna_length'             : 4.8,       # m
-    'antenna_width'              : 0.8,       # m
+    'antenna_length'             : 4.8,       # m, Bachmann et al. (2010)
+    'antenna_width'              : 0.7,       # m, Bachmann et al. (2010)
     'doppler_bandwidth'          : 2770,      # Hz
     'pulse_repetition_frequency' : 3800,      # Hz
     'chirp_bandwidth'            : 100e6,     # Hz
@@ -298,6 +303,18 @@ ICEYE = {
     'chirp_bandwidth'            : [37.6e6, 299e6], # Hz
 }
 
+# TeLEOS-2
+# launch date: 2023-04-22
+# end    date: operational
+# https://geo-insights.ai/wp-content/uploads/2024/06/ST-Engineering-Geo-Insights-TeLEOS-2-Datasheet.pdf
+# https://www.eoportal.org/satellite-missions/teleos-1
+TELEOS2 = {
+    # orbit
+    'altitude'                   : 574e3,           # m, near-equitorial
+    'orbit_inclination'          : 10,              # deg
+    # sar / antenna
+}
+
 
 ##--------------------  C-band  --------------------##
 
@@ -410,6 +427,7 @@ RCM = {
 # https://www.eoportal.org/satellite-missions/gaofen-3
 # Li et al. (2018, RS) at https://doi.org/10.3390/rs10121929
 # Table I in Yang et al. (2023, IEEE-TGRS) at https://doi.org/10.1109/TGRS.2023.3238707
+# Table 2 in Sun et al. (2017, RS) at https://doi.org/10.3390/s17102419
 GF3 = {
     # orbit
     'altitude'                   : 755e3,     # m
@@ -418,7 +436,7 @@ GF3 = {
     # sar / antenna
     'carrier_frequency'          : 5.4e9,     # Hz
     'antenna_length'             : 15,        # m
-    'antenna_width'              : 1.232,     # m
+    'antenna_width'              : 1.232,     # m, Table 2 in Sun et al. (2017)
     'pulse_repetition_frequency' : 1412.18,   # Hz
     'chirp_bandwidth'            : 60.00e6,   # Hz
     'sampling_frequency'         : 533.33e6,  # Hz, IF sampling
@@ -469,18 +487,21 @@ SEN = {
 # https://www.eoportal.org/satellite-missions/hj-1
 # Liu et al. (2014, J Radar), doi: 10.3724/SP.J.1300.2013.13050
 # Zhang et al. (2014, J Radar), doi: https://doi.org/10.3724/SP.J.1300.2014.13135
+# Yu et al. (2014, J Radar), doi: https://doi.org/10.3724/sp.J.1300.2013.13050
 # spatial resolution: 10 m (4 looks)
 # swath width: 100 km
 HJ1C = {
     # orbit
     'altitude'                   : 502e3,     # m
-    'orbit_inclination'          : 97.3,      # deg
+    'orbit_inclination'          : 97.3671,   # deg, Yu et al. (2014)
     'repeat_cycle'               : 31,        # day
     # sar / antenna
     'carrier_frequency'          : 3.13e9,    # Hz
+    'antenna_length'             : 6.0,       # m, Yu et al. (2014)
+    'antenna_width'              : 2.8,       # m, Yu et al. (2014)
     'pulse_repetition_frequency' : 2600,      # Hz, 2600-3700
     'chirp_bandwidth'            : 60.0e6,    # Hz
-    'noise_equivalent_sigma_zero': -22,       # dB
+    'noise_equivalent_sigma_zero': -19,       # dB, Yu et al. (2014)
 }
 
 # NISAR S-band
@@ -505,8 +526,10 @@ NISAR_S = {
 # Seasat
 # launch date: 1978-06-27
 # end    date: 1978-10-10
-# from Table 6-1 in Kim and Jordan (2006)
+# References:
+# Table 6-1 in Kim and Jordan (2006)
 # https://www.eoportal.org/satellite-missions/seasat
+# Table 1.2 in Curlander & Mcdonough (1991)
 SEASAT = {
     # orbit
     'altitude'                   : 787e3,     # m, mean value, 775-799 km
@@ -518,6 +541,7 @@ SEASAT = {
     'antenna_width'              : 2.16,      # m
     'pulse_repetition_frequency' : 1555,      # Hz, 1463-1647
     'chirp_bandwidth'            : 19e6,      # Hz
+    'noise_equivalent_sigma_zero': -18,       # dB, Table 1.2 in Curlander & Mcdonough (1991)
 }
 
 # JERS-1
@@ -613,6 +637,7 @@ ALOS2 = {
 # end    date: operational
 # https://www.eorc.jaxa.jp/ALOS/en/alos-4/a4_about_e.htm
 # https://www.eorc.jaxa.jp/ALOS/en/alos-4/a4_sensor_e.htm
+# https://www.eorc.jaxa.jp/ALOS/jp/activity/kyoto/pdf/2-07_KC25_ALOS4_Eng_A.pdf
 # using stripmap 200km@3m mode as reference
 ALOS4 = {
     # orbit (same as ALOS-2)
@@ -621,6 +646,8 @@ ALOS4 = {
     'repeat_cycle'               : 14,        # day, (15-3/14 rev/day)
     # sar / antenna
     'carrier_frequency'          : 1257.5e6,  # Hz (spotlight, 3m SM), 1236.5/1257.5/1278.5 MHz
+    'antenna_length'             : 3.7,       # m
+    'antenna_width'              : 10.0,      # m
     'chirp_bandwidth'            : 84e6,      # Hz, 84/42/28
     'range_resolution'           : 3,         # m
     'noise_equivalent_sigma_zero': -20,       # dB, -20/-24/-28
@@ -638,7 +665,7 @@ SAOCOM = {
     'orbit_inclination'          : 97.86,     # deg
     'repeat_cycle'               : 16,        # day, single satellite
     # sar / antenna
-    'carrrier_frequency'         : 1.27414e9, # Hz
+    'carrier_frequency'          : 1.27414e9, # Hz
     'antenna_length'             : 10,        # m
     'pulse_repetition_frequency' : 4545,      # Hz
     'sampling_frequency'         : 50.0e6,    # Hz
@@ -769,6 +796,7 @@ SENSOR_DICT = {
     'lt1'   : LT1,
     'uav'   : UAV_L,
     'ni'    : NISAR_L,
+    'saocom': SAOCOM,
     # P-band
     'bio'   : BIOMASS,
 }
