@@ -1195,7 +1195,7 @@ class ifgramStack:
         # to avoid the abnormal result as shown in https://github.com/insarlab/MintPy/pull/1063
         # This may be caused by the phase stitching during product preparation via ARIA-tools,
         # which could have broken the temporal consistency of the native unwrapped phase.
-        processor = self.metadata.get('mintpy.load.processor', 'isce')
+        processor = self.metadata.get('mintpy.load.processor', self.metadata.get('PROCESSOR', 'isce'))
         if ds_name == 'unwrapPhase' and processor in ['aria']:
             print(f'apply spatial referencing to {processor} products')
             ref_phase = self.get_reference_phase(dropIfgram=False)
