@@ -409,7 +409,7 @@ def prepare_stack(
     cols, rows = meta['WIDTH'], meta['LENGTH']
 
     # define (and fill out some) dataset structure
-    date12_arr = np.array([x.split("_") for x in date12_list], dtype=np.string_)
+    date12_arr = np.array([x.split("_") for x in date12_list], dtype=np.bytes_)
     drop_ifgram = np.ones(num_pair, dtype=np.bool_)
     ds_name_dict = {
         "date": [date12_arr.dtype, (num_pair, 2), date12_arr],
